# Change History

## 2022.6.27

* Updated development and test dependencies.
* ## 2021.10.24

* Intermediate release with new dev tools
* Changed name of package will deal with depreaction of the package under the old name [`prefix_compression`](https://pypi.org/project/prefix-compression/) later.
* No functional changes

## 0.0.1 (2021-05-08)

* Initial release on PyPI (as a different package `prefix_compression`)

